@@ -397,16 +397,15 @@ Accessible_getRelationSet (Accessible *obj)
 
   cspi_return_val_if_ev ("getRelationSet", NULL); 
   
-  /* this looks hack-ish, but it's based on the CORBA C bindings spec */
   n_relations = relation_set->_length;
-  relations = malloc (sizeof (AccessibleRelation *) * n_relations);
+  relations = malloc (sizeof (AccessibleRelation *) * (n_relations + 1));
   
   for (i = 0; i < n_relations; ++i)
     {
       relations[i] = cspi_object_add (CORBA_Object_duplicate (
 	      relation_set->_buffer[i], cspi_ev ()));
     }
-  relations[i] = CORBA_OBJECT_NIL;
+  relations[i] = NULL;
 
   CORBA_free (relation_set);
 
